EXPORTS
	??0CTestScheduler@@QAE@XZ @ 1 NONAME ; public: __thiscall CTestScheduler::CTestScheduler(void)
	??1CMsgServerTestUtils@@UAE@XZ @ 2 NONAME ; public: virtual __thiscall CMsgServerTestUtils::~CMsgServerTestUtils(void)
	?ChooseDriveL@CMsgServerTestUtils@@QAEXAAVTDriveUnit@@@Z @ 3 NONAME ; public: void __thiscall CMsgServerTestUtils::ChooseDriveL(class TDriveUnit &)
	?CleanMessageFolderL@CMsgServerTestUtils@@QAEXABVTDesC16@@@Z @ 4 NONAME ; public: void __thiscall CMsgServerTestUtils::CleanMessageFolderL(class TDesC16 const &)
	?Close@CMsgServerTestUtils@@QAEXH@Z @ 5 NONAME ; public: void __thiscall CMsgServerTestUtils::Close(int)
	?Complete@CMsgServerTestUtils@@QAEXXZ @ 6 NONAME ; public: void __thiscall CMsgServerTestUtils::Complete(void)
	?CorruptIndexFileL@CMsgServerTestUtils@@QAEXHABVTDesC16@@@Z @ 7 NONAME ; public: void __thiscall CMsgServerTestUtils::CorruptIndexFileL(int,class TDesC16 const &)
	?CreateDataFilesL@CMsgServerTestUtils@@QAEXABVTDesC16@@0VTUid@@@Z @ 8 NONAME ; public: void __thiscall CMsgServerTestUtils::CreateDataFilesL(class TDesC16 const &,class TDesC16 const &,class TUid)
	?CreateServerL@CMsgServerTestUtils@@QAEPAVCMsvServer@@ABVTDesC16@@@Z @ 9 NONAME ; public: class CMsvServer * __thiscall CMsgServerTestUtils::CreateServerL(class TDesC16 const &)
	?End@CMsgServerTestUtils@@QAEXXZ @ 10 NONAME ; public: void __thiscall CMsgServerTestUtils::End(void)
	?Error@CTestScheduler@@EBEXH@Z @ 11 NONAME ; private: virtual void __thiscall CTestScheduler::Error(int)const 
	?FileExists@CMsgServerTestUtils@@QAEXABVTDesC16@@@Z @ 12 NONAME ; public: void __thiscall CMsgServerTestUtils::FileExists(class TDesC16 const &)
	?FileMissing@CMsgServerTestUtils@@QAEXABVTDesC16@@@Z @ 13 NONAME ; public: void __thiscall CMsgServerTestUtils::FileMissing(class TDesC16 const &)
	?GetConfigL@CMsgServerTestUtils@@QAEXAAVTMsvConfig@@@Z @ 14 NONAME ; public: void __thiscall CMsgServerTestUtils::GetConfigL(class TMsvConfig &)
	?IndexSizeL@CMsgServerTestUtils@@QAEHHABVTDesC16@@@Z @ 15 NONAME ; public: int __thiscall CMsgServerTestUtils::IndexSizeL(int,class TDesC16 const &)
	?InstallMtmL@CMsgServerTestUtils@@QAEXABVTDesC16@@0VTUid@@@Z @ 16 NONAME ; public: void __thiscall CMsgServerTestUtils::InstallMtmL(class TDesC16 const &,class TDesC16 const &,class TUid)
	?NewL@CMsgServerTestUtils@@SAPAV1@AAVRTest@@@Z @ 17 NONAME ; public: static class CMsgServerTestUtils * __cdecl CMsgServerTestUtils::NewL(class RTest &)
	?NewLC@CMsgServerTestUtils@@SAPAV1@AAVRTest@@@Z @ 18 NONAME ; public: static class CMsgServerTestUtils * __cdecl CMsgServerTestUtils::NewLC(class RTest &)
	?Next@CMsgServerTestUtils@@QAEXABVTDesC16@@@Z @ 19 NONAME ; public: void __thiscall CMsgServerTestUtils::Next(class TDesC16 const &)
	?ReadInteger@CMsgServerTestUtils@@QAEHABVTDesC16@@AAH@Z @ 20 NONAME ; public: int __thiscall CMsgServerTestUtils::ReadInteger(class TDesC16 const &,int &)
	?RemoveIndexFile@CMsgServerTestUtils@@QAEXH@Z @ 21 NONAME ; public: void __thiscall CMsgServerTestUtils::RemoveIndexFile(int)
	?RemoveMailFolderL@CMsgServerTestUtils@@QAEXH@Z @ 22 NONAME ; public: void __thiscall CMsgServerTestUtils::RemoveMailFolderL(int)
	?SetConfigL@CMsgServerTestUtils@@QAEXAAVTMsvConfig@@@Z @ 23 NONAME ; public: void __thiscall CMsgServerTestUtils::SetConfigL(class TMsvConfig &)
	?SetDebugL@CMsgServerTestUtils@@QAEXH@Z @ 24 NONAME ; public: void __thiscall CMsgServerTestUtils::SetDebugL(int)
	?SetDriveL@CMsgServerTestUtils@@QAEXHH@Z @ 25 NONAME ; public: void __thiscall CMsgServerTestUtils::SetDriveL(int,int)
	?SetupL@CMsgServerTestUtils@@QAEXXZ @ 26 NONAME ; public: void __thiscall CMsgServerTestUtils::SetupL(void)
	?Start@CMsgServerTestUtils@@QAEXABVTDesC16@@@Z @ 27 NONAME ; public: void __thiscall CMsgServerTestUtils::Start(class TDesC16 const &)
	?WaitForKeyL@CMsgServerTestUtils@@QAEHVTTimeIntervalMicroSeconds32@@PAW4TKeyCode@@@Z @ 28 NONAME ; public: int __thiscall CMsgServerTestUtils::WaitForKeyL(class TTimeIntervalMicroSeconds32,enum TKeyCode *)
	?WaitForServerClose@CMsgServerTestUtils@@QAEXXZ @ 29 NONAME ; public: void __thiscall CMsgServerTestUtils::WaitForServerClose(void)

